// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <KPluginMetaData>

#include <QHash>
#include <QObject>
#include <QTimer>

namespace KTextEditor
{
class Document;
}
class QAction;
class QLabel;
class QWebEngineView;
class SitePreviewPlugin;

namespace KTextEditor {
class MainWindow;
}

class KPartView : public QObject
{
public:
    KPartView(SitePreviewPlugin *plugin, KTextEditor::MainWindow *mainWindow, QObject *parent);
    ~KPartView() override;

    QWidget *widget() const;

    void setDocument(KTextEditor::Document *document);
    KTextEditor::Document *document() const;

    void setAutoUpdating(bool autoUpdating);
    bool isAutoUpdating() const;

    void updatePreview();

    QUrl url() const;

protected:
    bool eventFilter(QObject *object, QEvent *event) override;

private:
    std::optional<QUrl> getURLFromFile(const QString &filePath);

    // generator implementations
    std::optional<QUrl> getURLFromFileHugo(const QString &filePath, const QString &baseDir);

    QLabel *m_errorLabel = nullptr;
    QWebEngineView  *m_part = nullptr;
    KTextEditor::Document *m_document = nullptr;

    bool m_autoUpdating = true;
    bool m_previewDirty = true;
    QTimer m_updateSquashingTimerFast;
    QTimer m_updateSquashingTimerSlow;
    QHash<QKeySequence, QAction *> m_shortcuts;
    KTextEditor::MainWindow *m_mainWindow;
    SitePreviewPlugin *m_plugin;
};
