// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <KPluginMetaData>
#include <KXMLGUIBuilder>

#include <QPointer>
#include <QStackedWidget>

#include <optional>

namespace KTextEditor
{
class Document;
class MainWindow;
class View;
}
class KToggleAction;
class KConfigGroup;
class SitePreviewPlugin;
class KPartView;

class PreviewWidget : public QStackedWidget
{
public:
    PreviewWidget(SitePreviewPlugin *plugin, KTextEditor::MainWindow *mainWindow, QWidget *parent);

    void readSessionConfig(const KConfigGroup &configGroup);
    void writeSessionConfig(KConfigGroup &configGroup) const;

protected:
    void showEvent(QShowEvent *event) override;
    void hideEvent(QHideEvent *event) override;

private Q_SLOTS:
    void setTextEditorView(KTextEditor::View *view);
    void resetTextEditorView(KTextEditor::Document *document);
    void unsetDocument(KTextEditor::Document *document);

private:
    void toggleDocumentLocking(bool locked);
    void toggleAutoUpdating(bool autoRefreshing);
    void updatePreview();

private:
    KToggleAction *m_lockAction;
    QAction *m_openExternallyAction;

    KTextEditor::MainWindow *const m_mainWindow;

    KTextEditor::Document *m_previewedTextEditorDocument = nullptr;
    KTextEditor::View *m_previewedTextEditorView = nullptr;
    QPointer<KPartView> m_partView;
    SitePreviewPlugin *m_plugin;
};
