// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#include "sitepreviewconfigpage.h"

#include <KLocalizedString>

#include "sitepreviewplugin.h"
#include "ui_config.h"

SitePreviewConfigPage::SitePreviewConfigPage(SitePreviewPlugin *plugin, QWidget *parent)
    : KTextEditor::ConfigPage(parent)
    , m_config(new Ui_config)
    , m_plugin(plugin)
{
    m_config->setupUi(this);

    connect(m_config->generatorComboBox_2, &QComboBox::currentIndexChanged, this, &SitePreviewConfigPage::slotMyChanged);
    connect(m_config->portSpinBox, &QSpinBox::valueChanged, this, &SitePreviewConfigPage::slotMyChanged);

    reset();
}

void SitePreviewConfigPage::reset()
{
    m_config->generatorComboBox_2->setCurrentIndex(static_cast<int>(m_plugin->generator()));
    m_config->portSpinBox->setValue(m_plugin->port());

    m_changed = false;
}

QString SitePreviewConfigPage::name() const
{
    return i18n("Site Preview");
}

QString SitePreviewConfigPage::fullName() const
{
    return i18n("Site Preview");
}

QIcon SitePreviewConfigPage::icon() const
{
    return QIcon::fromTheme(QLatin1String("globe-symbolic"));
}

void SitePreviewConfigPage::apply()
{
    if (!m_changed) {
        return;
    }

    m_plugin->setGenerator(static_cast<SitePreviewPlugin::Generator>(m_config->generatorComboBox_2->currentIndex()));
    m_plugin->setPort(m_config->portSpinBox->value());
}

void SitePreviewConfigPage::defaults()
{
    reset();
}

void SitePreviewConfigPage::slotMyChanged()
{
    m_changed = true;
    Q_EMIT changed();
}

#include "moc_sitepreviewconfigpage.cpp"
