// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#include "sitepreviewplugin.h"
#include "sitepreviewconfigpage.h"
#include "sitepreviewview.h"
#include "sitepreviewplugin_debug.h"

#include <KConfigGroup>
#include <KPluginFactory>
#include <KTextEditor/MainWindow>

#include <QProcess>

K_PLUGIN_FACTORY_WITH_JSON(SitePreviewPluginFactory, "sitepreviewplugin.json", registerPlugin<SitePreviewPlugin>();)

SitePreviewPlugin::SitePreviewPlugin(QObject *parent, const QVariantList & /*args*/)
    : KTextEditor::Plugin(parent)
{
}

SitePreviewPlugin::~SitePreviewPlugin() = default;

QObject *SitePreviewPlugin::createView(KTextEditor::MainWindow *mainwindow)
{
    return new KTextEditorPreviewView(this, mainwindow);
}

KTextEditor::ConfigPage *SitePreviewPlugin::configPage(int number, QWidget *parent)
{
    Q_UNUSED(number)
    Q_ASSERT(number == 0);
    return new SitePreviewConfigPage(this, parent);
}

int SitePreviewPlugin::configPages() const
{
    return 1;
}

void SitePreviewPlugin::writeSessionConfig(KConfigGroup &config)
{
    KConfigGroup scg(&config, QStringLiteral("Hugo"));
    scg.writeEntry(QStringLiteral("Generator"), static_cast<int>(m_selectedGenerator));
    scg.writeEntry(QStringLiteral("Port"), m_port);
}

void SitePreviewPlugin::readSessionConfig(const KConfigGroup &config)
{
    const KConfigGroup scg(&config, QStringLiteral("Hugo"));
    m_selectedGenerator = static_cast<Generator>(scg.readEntry<int>(QStringLiteral("Generator"), static_cast<int>(Generator::Hugo)));
    m_port = scg.readEntry<int>(QStringLiteral("Port"), 1313);
}

SitePreviewPlugin::Generator SitePreviewPlugin::generator() const
{
    return m_selectedGenerator;
}

int SitePreviewPlugin::port() const
{
    return m_port;
}

void SitePreviewPlugin::setGenerator(SitePreviewPlugin::Generator generator)
{
    m_selectedGenerator = generator;
}

void SitePreviewPlugin::setPort(int port)
{
    m_port = port;
}

#include "sitepreviewplugin.moc"
