// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <KTextEditor/Plugin>
#include <KTextEditor/SessionConfigInterface>

class SitePreviewPlugin : public KTextEditor::Plugin, public KTextEditor::SessionConfigInterface
{
    Q_OBJECT
    Q_INTERFACES(KTextEditor::SessionConfigInterface)

public:
    SitePreviewPlugin(QObject *parent, const QVariantList &args);
    ~SitePreviewPlugin() override;

    enum class Generator {
        Hugo,
    };
    Q_ENUM(Generator)

    QObject *createView(KTextEditor::MainWindow *mainWindow) override;
    [[nodiscard]] int configPages() const override;
    KTextEditor::ConfigPage * configPage(int number, QWidget *parent) override;
    void readSessionConfig(const KConfigGroup &config) override;
    void writeSessionConfig (KConfigGroup& config) override;

    [[nodiscard]] Generator generator() const;
    void setGenerator(Generator generator);

    [[nodiscard]] int port() const;
    void setPort(int port);

private:
    Generator m_selectedGenerator = Generator::Hugo;
    int m_port = 1313;
};
