// SPDX-FileCopyrightText: 2025 Joshua Goins <josh@redstrate.com>
// SPDX-License-Identifier: LGPL-2.0-or-later

#pragma once

#include <KTextEditor/SessionConfigInterface>
#include <KXMLGUIClient>

#include <QObject>
#include <QPointer>
#include <QProcess>

class PreviewWidget;

namespace KTextEditor
{
class MainWindow;
class View;
}

class SitePreviewPlugin;
class QWidget;

class KTextEditorPreviewView : public QObject, public KXMLGUIClient, public KTextEditor::SessionConfigInterface
{
    Q_OBJECT
    Q_INTERFACES(KTextEditor::SessionConfigInterface)

public:
    KTextEditorPreviewView(SitePreviewPlugin *plugin, KTextEditor::MainWindow *mainWindow);
    ~KTextEditorPreviewView() override;

    void readSessionConfig(const KConfigGroup &config) override;
    void writeSessionConfig(KConfigGroup &config) override;

private:
    void startHugo();
    void stopHugo();

    QPointer<QWidget> m_toolView;
    PreviewWidget *m_previewView;
    QProcess m_hugoProcess;
    KTextEditor::MainWindow *m_mainWindow;
    QAction *m_startHugoAction;
    QAction *m_stopHugoAction;
    SitePreviewPlugin *m_plugin;
};
